TxConfirmParams class

Constructors

TxConfirmParams({String? module, String? call, Map? txDisplay, List? params, String? rawParams, bool? isUnsigned, String? txTitle, String? txName})

Properties

call → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isUnsigned → bool?
final
module → String?
final
params → List?
final
rawParams → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txDisplay → Map?
final
txName → String?
final
txTitle → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited